package model

import (
	"time"
)

type MallOrd struct {
	OrdId                    int64     `json:"ord_id" xorm:"not null pk BIGINT(20)"`
	MainOrdId                int64     `json:"main_ord_id" xorm:"not null comment('主订单号') index BIGINT(20)"`
	Uid                      int       `json:"uid" xorm:"comment('用户id') index INT(11)"`
	BuyerName                string    `json:"buyer_name" xorm:"comment('购买人') VARCHAR(255)"`
	IsSetSubsidy             int       `json:"is_set_subsidy" xorm:"comment('') default '0' INT(11)"`
	BuyerPhone               string    `json:"buyer_phone" xorm:"comment('购买人手机号') VARCHAR(255)"`
	CostPrice                string    `json:"cost_price" xorm:"comment('价格') DECIMAL(12,2)"`
	DeductCoin               string    `json:"deduct_coin" xorm:"comment('抵扣券') DECIMAL(12,2)"`
	CostVirtualCoin          string    `json:"cost_virtual_coin" xorm:"comment('消耗的虚拟币') DECIMAL(12,2)"`
	VirtualCoinId            int       `json:"virtual_coin_id" xorm:"comment('使用的虚拟币id') INT(11)"`
	State                    int       `json:"state" xorm:"comment('订单状态：0未支付 1已支付 2已发货 3已完成 4售后中 5部分售后中 6关闭') TINYINT(1)"`
	PayTime                  time.Time `json:"pay_time" xorm:"comment('支付时间') DATETIME"`
	PayChannel               int       `json:"pay_channel" xorm:"not null comment('支付方式：1balance 2alipay 3wx_pay') TINYINT(1)"`
	ShippingTime             time.Time `json:"shipping_time" xorm:"comment('发货时间') DATETIME"`
	LogisticCompany          string    `json:"logistic_company" xorm:"not null default '' comment('物流公司') VARCHAR(255)"`
	LogisticNum              string    `json:"logistic_num" xorm:"not null default '' comment('物流单号') VARCHAR(255)"`
	ReceiverPhone            string    `json:"receiver_phone" xorm:"not null default '' comment('收货人手机号') VARCHAR(20)"`
	ReceiverName             string    `json:"receiver_name" xorm:"not null default '' comment('收货人名字') VARCHAR(255)"`
	ReceiverAddressDetail    string    `json:"receiver_address_detail" xorm:"not null default '' comment('收货人地址') VARCHAR(255)"`
	ShippingType             int       `json:"shipping_type" xorm:"not null default 1 comment('运送方式：1快递送货') TINYINT(1)"`
	CouponDiscount           string    `json:"coupon_discount" xorm:"not null default 0.00 comment('优惠券折扣额') DECIMAL(12,2)"`
	DiscountPrice            string    `json:"discount_price" xorm:"not null default 0.00 comment('立减') DECIMAL(12,2)"`
	UserCouponId             int64     `json:"user_coupon_id" xorm:"comment('使用的优惠券id') BIGINT(20)"`
	ReturnInsuranceFee       string    `json:"return_insurance_fee" xorm:"not null default 0.00 comment('退货无忧费用') DECIMAL(12,2)"`
	IsReceipt                int       `json:"is_receipt" xorm:"not null default 0 comment('是否开具发票 0否 1是') TINYINT(255)"`
	ShippingFee              string    `json:"shipping_fee" xorm:"not null default 0.00 comment('运费') DECIMAL(12,2)"`
	Comment                  string    `json:"comment" xorm:"not null comment('备注') VARCHAR(2048)"`
	ProvinceName             string    `json:"province_name" xorm:"not null default '' comment('收货省份') VARCHAR(255)"`
	CityName                 string    `json:"city_name" xorm:"not null default '' comment('收货城市') VARCHAR(255)"`
	CountyName               string    `json:"county_name" xorm:"not null default '' comment('收货区域') VARCHAR(255)"`
	PayNum                   string    `json:"pay_num" xorm:"not null default '' comment('交易流水') VARCHAR(255)"`
	ConfirmTime              time.Time `json:"confirm_time" xorm:"comment('确认时间') DATETIME"`
	EstimateIntegral         string    `json:"estimate_integral" xorm:"not null default 0.0000 comment('预计积分') DECIMAL(12,4)"`
	EstimateCommission       string    `json:"estimate_commission" xorm:"not null default 0.0000 comment('预计佣金') DECIMAL(12,4)"`
	CreateTime               time.Time `json:"create_time" xorm:"not null default 'CURRENT_TIMESTAMP' comment('创建时间') DATETIME"`
	UpdateTime               time.Time `json:"update_time" xorm:"not null default 'CURRENT_TIMESTAMP' comment('更新时间') DATETIME"`
	DeletedTime              time.Time `json:"deleted_time" xorm:"comment('删除时间') DATETIME"`
	FinishTime               time.Time `json:"finish_time" xorm:"comment('完成时间') DATETIME"`
	OrderType                int       `json:"order_type" xorm:"not null default 1 comment('订单类型：1普通订单 2拼团订单 3秒杀 4超级拼团 5会员礼包') TINYINT(3)"`
	Data                     string    `json:"data" xorm:"comment('订单相关的数据') TEXT"`
	GroupBuyCommission       string    `json:"group_buy_commission" xorm:"default 0.0000 comment('团购未中奖佣金') DECIMAL(12,4)"`
	GroupBuySettleTime       time.Time `json:"group_buy_settle_time" xorm:"comment('拼团结算时间[废弃 合并到settle_time]') DATETIME"`
	SettleTime               time.Time `json:"settle_time" xorm:"comment('结算时间') DATETIME"`
	GroupBuyCommissionTime   time.Time `json:"group_buy_commission_time" xorm:"comment('拼团分佣时间[废弃 合并到commission_tiem]') DATETIME"`
	CommissionTime           time.Time `json:"commission_time" xorm:"comment('分佣时间') DATETIME"`
	ShareUid                 int       `json:"share_uid" xorm:"comment('分享人') INT(11)"`
	IsConsign                int       `json:"is_consign" xorm:"not null default 0 comment('是否是超级拼团寄售0否1是') TINYINT(1)"`
	UserLevelData            string    `json:"user_level_data" xorm:"comment('会员礼包相关') TEXT"`
	ReturnMoneySettleAt      int       `json:"return_money_settle_at" xorm:"comment('返现金额结算') INT(11)"`
	IsSetReduce              int       `xorm:"not null default 0 INT(1)" json:"is_set_reduce"`
	IsSetOutAch              int       `xorm:"not null default 0 INT(1)" json:"is_set_out_ach"`
	IsSubsidyEnd             int       `xorm:"not null default 0 INT(1)" json:"is_subsidy_end"`
	RunTime                  int       `xorm:"not null default 0 INT(11)" json:"run_time"`
	ConsumptionCoinReward    string    `json:"consumption_coin_reward" xorm:"default 0.000000 comment('当前计算金额') DECIMAL(16,6)"`
	DeductCoinReward         string    `json:"deduct_coin_reward" xorm:"default 0.000000 comment('当前计算金额') DECIMAL(16,6)"`
	ConsumptionCoinRewardOut string    `json:"consumption_coin_reward_out" xorm:"default 0.000000 comment('出局的金额') DECIMAL(16,6)"`
	DeductCoinRewardOut      string    `json:"deduct_coin_reward_out" xorm:"default 0.000000 comment('出局的计算金额') DECIMAL(16,6)"`
	PayOnBehalfUid           int       `json:"pay_on_behalf_uid" xorm:"comment('0') INT(11)"`
}
