package model

import (
	"time"
)

type O2oOrd struct {
	OrdId                 int64     `json:"ord_id" xorm:"not null pk BIGINT(20)"`
	MainOrdId             int64     `json:"main_ord_id" xorm:"not null comment('主订单号') index BIGINT(20)"`
	Uid                   int       `json:"uid" xorm:"comment('用户id') index INT(11)"`
	BelongStoreId         int       `json:"belong_store_id" xorm:"comment('归属店铺id') INT(11)"`
	BuyerName             string    `json:"buyer_name" xorm:"comment('购买人') VARCHAR(255)"`
	BuyerPhone            string    `json:"buyer_phone" xorm:"comment('购买人手机号') VARCHAR(255)"`
	CostPrice             string    `json:"cost_price" xorm:"comment('价格') DECIMAL(12,2)"`
	CostVirtualCoin       string    `json:"cost_virtual_coin" xorm:"comment('消耗的虚拟币') DECIMAL(12,2)"`
	VirtualCoinId         int       `json:"virtual_coin_id" xorm:"comment('使用的虚拟币id') INT(11)"`
	State                 int       `json:"state" xorm:"comment('订单状态：0未支付 1已支付 ...(其余状态根据订单类型不同)') TINYINT(1)"`
	PayTime               time.Time `json:"pay_time" xorm:"comment('支付时间') DATETIME"`
	PickUp                int       `json:"pick_up" xorm:"not null comment('取货方式：1堂食 2打包带走') TINYINT(1)"`
	PayChannel            int       `json:"pay_channel" xorm:"not null comment('支付方式：1balance 2alipay 3wx_pay 4zhios_pay_alipay') TINYINT(1)"`
	ShippingTime          time.Time `json:"shipping_time" xorm:"comment('发货时间') DATETIME"`
	LogisticCompany       string    `json:"logistic_company" xorm:"not null default '' comment('物流公司') VARCHAR(255)"`
	LogisticNum           string    `json:"logistic_num" xorm:"not null default '' comment('物流单号') VARCHAR(255)"`
	ReceiverPhone         string    `json:"receiver_phone" xorm:"not null default '' comment('收货人手机号') VARCHAR(20)"`
	ReceiverName          string    `json:"receiver_name" xorm:"not null default '' comment('收货人名字') VARCHAR(255)"`
	ReceiverAddressDetail string    `json:"receiver_address_detail" xorm:"not null default '' comment('收货人地址') VARCHAR(255)"`
	ShippingType          int       `json:"shipping_type" xorm:"not null default 1 comment('运送方式：1快递送货') TINYINT(1)"`
	CouponDiscount        string    `json:"coupon_discount" xorm:"not null default 0.00 comment('优惠券折扣额') DECIMAL(12,2)"`
	DiscountPrice         string    `json:"discount_price" xorm:"not null default 0.00 comment('立减') DECIMAL(12,2)"`
	UserCouponId          int64     `json:"user_coupon_id" xorm:"comment('使用的优惠券id') BIGINT(20)"`
	ReturnInsuranceFee    string    `json:"return_insurance_fee" xorm:"not null default 0.00 comment('退货无忧费用') DECIMAL(12,2)"`
	IsReceipt             int       `json:"is_receipt" xorm:"not null default 0 comment('是否开具发票 0否 1是') TINYINT(255)"`
	ShippingFee           string    `json:"shipping_fee" xorm:"not null default 0.00 comment('运费') DECIMAL(12,2)"`
	Comment               string    `json:"comment" xorm:"not null comment('备注') VARCHAR(2048)"`
	ProvinceName          string    `json:"province_name" xorm:"not null default '' comment('收货省份') VARCHAR(255)"`
	CityName              string    `json:"city_name" xorm:"not null default '' comment('收货城市') VARCHAR(255)"`
	CountyName            string    `json:"county_name" xorm:"not null default '' comment('收货区域') VARCHAR(255)"`
	PayNum                string    `json:"pay_num" xorm:"not null default '' comment('交易流水') VARCHAR(255)"`
	ConfirmTime           time.Time `json:"confirm_time" xorm:"comment('确认时间') DATETIME"`
	EstimateCommission    string    `json:"estimate_commission" xorm:"not null default 0.0000 comment('预计佣金（三方分账完之后站长的佣金）') DECIMAL(12,4)"`
	CreateTime            time.Time `json:"create_time" xorm:"not null default 'CURRENT_TIMESTAMP' comment('创建时间') DATETIME"`
	UpdateTime            time.Time `json:"update_time" xorm:"not null default 'CURRENT_TIMESTAMP' comment('更新时间') DATETIME"`
	DeletedTime           time.Time `json:"deleted_time" xorm:"comment('删除时间') DATETIME"`
	FinishTime            time.Time `json:"finish_time" xorm:"comment('完成时间') DATETIME"`
	OrderType             int       `json:"order_type" xorm:"not null default 1 comment('订单类型：1(小店订单)') TINYINT(3)"`
	Data                  string    `json:"data" xorm:"not null comment('订单相关的数据') TEXT"`
	SettleTime            time.Time `json:"settle_time" xorm:"comment('结算时间') DATETIME"`
	CommissionTime        time.Time `json:"commission_time" xorm:"comment('分佣时间') DATETIME"`
	ShareUid              int       `json:"share_uid" xorm:"comment('分享人') INT(11)"`
	TotalPrice            float32   `json:"total_price" xorm:"comment('订单总金额') FLOAT(8,2)"`
	PickUpNum             string    `json:"pick_up_num" xorm:"comment('取餐号') VARCHAR(255)"`
	TradeNo               string    `json:"trade_no" xorm:"comment('支付平台的订单号') VARCHAR(50)"`
	PayTradeNo            string    `json:"pay_trade_no" xorm:"comment('支付联盟支付的订单号') VARCHAR(50)"`
	ConsumptionType       int       `json:"consumption_type" xorm:"not null default 1 comment('消费类型：1到店消费2立即制作') TINYINT(1)"`
	TableNum              string    `json:"table_num" xorm:"default '' comment('桌号') VARCHAR(12)"`
	IsThreePartySplit     int       `json:"is_three_party_split" xorm:"comment('是否进行了三方分账,0：否，1:是') TINYINT(1)"`
	MainCommission        string    `json:"main_commission" xorm:"not null default 0.0000 comment('总佣金') DECIMAL(12,4)"`
	SkuPriceInfo          string    `json:"sku_price_info" xorm:"comment('新版本支付规则（规则计算信息）') VARCHAR(500)"`
	PlatformCommission    string    `json:"platform_commission" xorm:"comment('平台所得的佣金(平台不是站长)') DECIMAL(12,4)"`
	MealFee               string    `json:"meal_fee" xorm:"comment('餐位费') VARCHAR(50)"`
	ReturnMoneySettleAt   int       `json:"return_money_settle_at" xorm:"default 0 comment('小口袋定制返现时间') INT(11)"`
	IsSetReduce           int       `json:"is_set_reduce" xorm:"default 0 comment('小口袋定制设置退回 0否 1是') INT(1)"`
	IsSetOutAch           int       `xorm:"not null default 0 INT(1)" json:"is_set_out_ach"`
}
